"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ElectronClipboardService = exports.INativeClipboardService = exports.CLIPBOARD_FILE_TOKEN = void 0;
const tslib_1 = require("tslib");
const di_1 = require("@opensumi/di");
const ide_core_common_1 = require("@opensumi/ide-core-common");
Object.defineProperty(exports, "CLIPBOARD_FILE_TOKEN", { enumerable: true, get: function () { return ide_core_common_1.CLIPBOARD_FILE_TOKEN; } });
const electron_1 = require("@opensumi/ide-core-common/lib/electron");
exports.INativeClipboardService = Symbol('INativeClipboardService');
let ElectronClipboardService = class ElectronClipboardService {
    async writeText(text) {
        return await this.electronMainUIService.writeClipboardText(text);
    }
    async readText() {
        return await this.electronMainUIService.readClipboardText();
    }
    async writeResources(resources, field = ide_core_common_1.CLIPBOARD_FILE_TOKEN) {
        try {
            const buffer = Buffer.from(JSON.stringify(resources.map((uri) => uri.toString())), 'utf8');
            return await this.electronMainUIService.writeClipboardBuffer(field, buffer);
        }
        catch (_a) { }
    }
    async readResources(field = ide_core_common_1.CLIPBOARD_FILE_TOKEN) {
        try {
            const buffer = await this.electronMainUIService.readClipboardBuffer(field);
            const list = JSON.parse(Buffer.from(buffer).toString('utf8'));
            if (!Array.isArray(list) ||
                !list.length ||
                !list.every((str) => typeof str === 'string' && ide_core_common_1.URI.isUriString(str))) {
                return [];
            }
            return list.map((str) => ide_core_common_1.URI.parse(str));
        }
        catch (_a) {
            return [];
        }
    }
    async hasResources(field) {
        try {
            const buffer = await this.electronMainUIService.readClipboardBuffer(field !== null && field !== void 0 ? field : ide_core_common_1.CLIPBOARD_FILE_TOKEN);
            const list = JSON.parse(Buffer.from(buffer).toString('utf8'));
            if (!Array.isArray(list) ||
                !list.length ||
                !list.every((str) => typeof str === 'string' && ide_core_common_1.URI.isUriString(str))) {
                return false;
            }
            return true;
        }
        catch (_a) {
            return false;
        }
    }
};
tslib_1.__decorate([
    (0, di_1.Autowired)(electron_1.IElectronMainUIService),
    tslib_1.__metadata("design:type", Object)
], ElectronClipboardService.prototype, "electronMainUIService", void 0);
ElectronClipboardService = tslib_1.__decorate([
    (0, di_1.Injectable)()
], ElectronClipboardService);
exports.ElectronClipboardService = ElectronClipboardService;
//# sourceMappingURL=index.js.map