"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ElectronHeaderService = exports.DEFAULT_TEMPLATE = exports.SEPARATOR = exports.TITLE_DIRTY = void 0;
const tslib_1 = require("tslib");
const di_1 = require("@opensumi/di");
const ide_core_browser_1 = require("@opensumi/ide-core-browser");
const browser_1 = require("@opensumi/ide-editor/lib/browser");
const path_1 = require("@opensumi/ide-utils/lib/path");
const strings_1 = require("@opensumi/ide-utils/lib/strings");
// "● "
exports.TITLE_DIRTY = '\u25cf ';
exports.SEPARATOR = ' - ';
exports.DEFAULT_TEMPLATE = '${dirty}${activeEditorShort}${separator}${rootName}';
if (ide_core_browser_1.isMacintosh) {
    exports.DEFAULT_TEMPLATE = '${activeEditorShort}${separator}${rootName}';
}
let ElectronHeaderService = class ElectronHeaderService extends ide_core_browser_1.WithEventBus {
    get titleTemplate() {
        return this._titleTemplate;
    }
    set titleTemplate(value) {
        this._titleTemplate = value;
        this.updateAppTitle();
    }
    setTemplateVariables(key, value) {
        this._templateVariables[key] = value;
    }
    constructor() {
        super();
        this.disposableCollection = new ide_core_browser_1.DisposableCollection();
        this._onTitleChanged = new ide_core_browser_1.Emitter();
        this.onTitleChanged = this._onTitleChanged.event;
        this.separator = exports.SEPARATOR;
        this._titleTemplate = exports.DEFAULT_TEMPLATE;
        this._templateVariables = {};
        this.disposableCollection.push(this.editorService.onActiveResourceChange(() => {
            this.updateAppTitle();
        }));
    }
    onResourceDidUpdateEvent() {
        this.updateAppTitle();
    }
    updateAppTitle() {
        this._onTitleChanged.fire(this.appTitle);
    }
    get appTitle() {
        const formatted = this.formatAppTitle();
        let result = formatted;
        if (this.appConfig.extensionDevelopmentHost) {
            result = `[${(0, ide_core_browser_1.localize)('workspace.development.title')}] ${result}`;
        }
        if (this.appConfig.isRemote) {
            result = `[${(0, ide_core_browser_1.localize)('common.remoteMode')}] ${result}`;
        }
        this._appTitle = result;
        return this._appTitle;
    }
    formatAppTitle() {
        var _a, _b, _c;
        const { appConfig } = this;
        const currentResource = this.editorService.currentResource;
        const currentEditor = this.editorService.currentEditor;
        const workspaceDir = appConfig.workspaceDir ? appConfig.workspaceDir : '';
        const workspaceBasename = (0, path_1.basename)(workspaceDir);
        const activeEditorFull = (_a = currentResource === null || currentResource === void 0 ? void 0 : currentResource.name) !== null && _a !== void 0 ? _a : '';
        const activeEditorRelative = activeEditorFull && workspaceDir ? makeRelativePath(workspaceDir, activeEditorFull) : '';
        const activeFolderFull = activeEditorFull ? (0, path_1.dirname)(activeEditorFull) : '';
        const activeFolderRelative = activeFolderFull && workspaceDir ? makeRelativePath(workspaceDir, activeFolderFull) : '';
        const activeEditorShort = (0, path_1.basename)(activeEditorFull);
        const activeEditorMedium = activeEditorRelative;
        const activeEditorLong = activeEditorFull;
        const activeFolderShort = (0, path_1.basename)(activeFolderFull);
        const activeFolderMedium = activeFolderRelative;
        const activeFolderLong = activeFolderFull;
        const folderName = workspaceBasename;
        const folderPath = workspaceDir;
        const rootName = workspaceBasename;
        const rootPath = workspaceDir;
        const appName = (_b = (0, ide_core_browser_1.replaceLocalizePlaceholder)(appConfig.appName)) !== null && _b !== void 0 ? _b : '';
        // TODO: 当前 OpenSumi 还不支持 Remote 名字
        const remoteName = '';
        const dirty = ((_c = currentEditor === null || currentEditor === void 0 ? void 0 : currentEditor.currentDocumentModel) === null || _c === void 0 ? void 0 : _c.dirty) ? exports.TITLE_DIRTY : '';
        const result = (0, strings_1.template)(this.titleTemplate, Object.assign({ activeEditorShort,
            activeEditorMedium,
            activeEditorLong,
            activeFolderShort,
            activeFolderMedium,
            activeFolderLong,
            folderName,
            folderPath,
            rootName,
            rootPath,
            appName,
            remoteName,
            dirty }, this._templateVariables), {
            separator: this.separator,
        });
        return result;
    }
    dispose() {
        this.disposableCollection.dispose();
    }
};
tslib_1.__decorate([
    (0, di_1.Autowired)(browser_1.WorkbenchEditorService),
    tslib_1.__metadata("design:type", browser_1.WorkbenchEditorService)
], ElectronHeaderService.prototype, "editorService", void 0);
tslib_1.__decorate([
    (0, di_1.Autowired)(ide_core_browser_1.AppConfig),
    tslib_1.__metadata("design:type", Object)
], ElectronHeaderService.prototype, "appConfig", void 0);
tslib_1.__decorate([
    (0, ide_core_browser_1.OnEvent)(browser_1.ResourceDidUpdateEvent),
    tslib_1.__metadata("design:type", Function),
    tslib_1.__metadata("design:paramtypes", []),
    tslib_1.__metadata("design:returntype", void 0)
], ElectronHeaderService.prototype, "onResourceDidUpdateEvent", null);
ElectronHeaderService = tslib_1.__decorate([
    (0, di_1.Injectable)(),
    tslib_1.__metadata("design:paramtypes", [])
], ElectronHeaderService);
exports.ElectronHeaderService = ElectronHeaderService;
function makeRelativePath(workspaceDir, path) {
    if (!path || !workspaceDir) {
        return '';
    }
    workspaceDir = (0, path_1.toSlashes)(workspaceDir);
    path = (0, path_1.toSlashes)(path);
    if (!workspaceDir.endsWith(path_1.posix.sep)) {
        workspaceDir += path_1.posix.sep;
    }
    if (path.startsWith(workspaceDir)) {
        return path.substring(workspaceDir.length);
    }
    return path;
}
//# sourceMappingURL=header.service.js.map