"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.HeaderBarTitleComponent = exports.ElectronHeaderBar = exports.HeaderBarRightComponent = exports.HeaderBarLeftComponent = void 0;
const tslib_1 = require("tslib");
const classnames_1 = tslib_1.__importDefault(require("classnames"));
const mobx_react_lite_1 = require("mobx-react-lite");
const react_1 = tslib_1.__importStar(require("react"));
const ide_core_browser_1 = require("@opensumi/ide-core-browser");
const constants_1 = require("@opensumi/ide-core-browser/lib/layout/constants");
const electron_1 = require("@opensumi/ide-core-common/lib/electron");
const header_1 = require("../../common/header");
const header_module_less_1 = tslib_1.__importDefault(require("./header.module.less"));
const useFullScreen = () => {
    const uiService = (0, ide_core_browser_1.useInjectable)(electron_1.IElectronMainUIService);
    const [isFullScreen, setFullScreen] = (0, react_1.useState)(false);
    (0, react_1.useEffect)(() => {
        uiService.isFullScreen(ide_core_browser_1.electronEnv.currentWindowId).then((fullScreen) => {
            setFullScreen(fullScreen);
        });
        const listener = uiService.on('fullScreenStatusChange', (windowId, fullScreen) => {
            if (windowId === ide_core_browser_1.electronEnv.currentWindowId) {
                setFullScreen(fullScreen);
            }
        });
        return () => {
            listener.dispose();
        };
    }, []);
    return {
        isFullScreen,
    };
};
const useMaximize = () => {
    const uiService = (0, ide_core_browser_1.useInjectable)(electron_1.IElectronMainUIService);
    const [maximized, setMaximized] = (0, react_1.useState)(false);
    const getMaximized = async () => uiService.isMaximized(ide_core_browser_1.electronEnv.currentWindowId);
    (0, react_1.useEffect)(() => {
        const maximizeListener = uiService.on('maximizeStatusChange', (windowId, isMaximized) => {
            if (windowId === ide_core_browser_1.electronEnv.currentWindowId) {
                setMaximized(isMaximized);
            }
        });
        getMaximized().then((maximized) => {
            setMaximized(maximized);
        });
        return () => {
            maximizeListener.dispose();
        };
    }, []);
    return {
        maximized,
        getMaximized,
    };
};
const HeaderBarLeftComponent = () => {
    const componentRegistry = (0, ide_core_browser_1.useInjectable)(ide_core_browser_1.ComponentRegistry);
    if (ide_core_browser_1.isMacintosh) {
        return null;
    }
    const initialProps = {
        className: 'menubarWrapper',
    };
    return (react_1.default.createElement(react_1.default.Fragment, null,
        react_1.default.createElement(ide_core_browser_1.ComponentRenderer, { Component: componentRegistry.getComponentRegistryInfo('@opensumi/ide-menu-bar').views[0].component, initialProps: initialProps })));
};
exports.HeaderBarLeftComponent = HeaderBarLeftComponent;
const HeaderBarRightComponent = () => {
    const { maximized } = useMaximize();
    const windowService = (0, ide_core_browser_1.useInjectable)(ide_core_browser_1.IWindowService);
    const layoutViewSize = (0, ide_core_browser_1.useInjectable)(constants_1.LayoutViewSizeConfig);
    if (ide_core_browser_1.isMacintosh) {
        return null;
    }
    return (react_1.default.createElement("div", { className: header_module_less_1.default.windowActions, style: {
            height: layoutViewSize.calcElectronHeaderHeight(),
        } },
        react_1.default.createElement("div", { className: (0, classnames_1.default)(header_module_less_1.default.icon, (0, ide_core_browser_1.getIcon)('min')), onClick: () => windowService.minimize() }),
        maximized ? (react_1.default.createElement("div", { className: (0, classnames_1.default)(header_module_less_1.default.icon, (0, ide_core_browser_1.getIcon)('max')), onClick: () => windowService.unmaximize() })) : (react_1.default.createElement("div", { className: (0, classnames_1.default)(header_module_less_1.default.icon, (0, ide_core_browser_1.getIcon)('unmax')), onClick: () => windowService.maximize() })),
        react_1.default.createElement("div", { className: (0, classnames_1.default)(header_module_less_1.default.icon, (0, ide_core_browser_1.getIcon)('close1')), onClick: () => windowService.close() })));
};
exports.HeaderBarRightComponent = HeaderBarRightComponent;
/**
 * autoHide: Hide the HeaderBar when the macOS full screen
 */
exports.ElectronHeaderBar = (0, mobx_react_lite_1.observer)(({ LeftComponent, RightComponent, TitleComponent, autoHide = true, height, }) => {
    const windowService = (0, ide_core_browser_1.useInjectable)(ide_core_browser_1.IWindowService);
    const layoutViewSize = (0, ide_core_browser_1.useInjectable)(constants_1.LayoutViewSizeConfig);
    const { isFullScreen } = useFullScreen();
    const { getMaximized } = useMaximize();
    if (!LeftComponent) {
        LeftComponent = exports.HeaderBarLeftComponent;
    }
    if (!RightComponent) {
        RightComponent = exports.HeaderBarRightComponent;
    }
    if (!TitleComponent) {
        TitleComponent = exports.HeaderBarTitleComponent;
    }
    const safeHeight = (0, react_1.useMemo)(() => {
        if (height) {
            return height;
        }
        return layoutViewSize.calcElectronHeaderHeight();
    }, [layoutViewSize, height]);
    // in Mac, hide the header bar if it is in full screen mode
    if (ide_core_browser_1.isMacintosh && isFullScreen && autoHide) {
        return (react_1.default.createElement("div", null,
            react_1.default.createElement(TitleComponent, { hidden: true })));
    }
    return (react_1.default.createElement("div", { className: header_module_less_1.default.header, style: { height: safeHeight }, onDoubleClick: async () => {
            if (await getMaximized()) {
                windowService.unmaximize();
            }
            else {
                windowService.maximize();
            }
        } },
        react_1.default.createElement(LeftComponent, null),
        react_1.default.createElement(TitleComponent, null),
        react_1.default.createElement(RightComponent, null)));
});
exports.HeaderBarTitleComponent = (0, mobx_react_lite_1.observer)(({ hidden }) => {
    const headerService = (0, ide_core_browser_1.useInjectable)(header_1.IElectronHeaderService);
    const ref = (0, react_1.useRef)(null);
    const spanRef = (0, react_1.useRef)(null);
    const [appTitle, setAppTitle] = (0, react_1.useState)(headerService.appTitle);
    (0, ide_core_browser_1.useEventEffect)(headerService.onTitleChanged, (v) => {
        setAppTitle(v);
    }, []);
    (0, react_1.useEffect)(() => {
        setPosition();
        const disposer = new ide_core_browser_1.Disposable();
        disposer.addDispose(new ide_core_browser_1.DomListener(window, 'resize', () => {
            setPosition();
        }));
        if (ref.current && ref.current.previousElementSibling) {
            const resizeObserver = new ResizeObserver(setPosition);
            resizeObserver.observe(ref.current.previousElementSibling);
            disposer.addDispose({
                dispose: () => {
                    resizeObserver.disconnect();
                },
            });
        }
        return disposer.dispose.bind(disposer);
    }, []);
    function setPosition() {
        // 在下一个 animationFrame 执行，此时 spanRef.current!.offsetWidth 的宽度才是正确的
        window.requestAnimationFrame(() => {
            if (ref.current && spanRef.current) {
                const windowWidth = window.innerWidth;
                let prevWidth = 0;
                let node = ref.current.previousElementSibling;
                while (node) {
                    prevWidth += node.offsetWidth;
                    node = node.previousElementSibling;
                }
                const left = Math.max(0, windowWidth * 0.5 - prevWidth - spanRef.current.offsetWidth * 0.5);
                ref.current.style.paddingLeft = left + 'px';
            }
        });
    }
    // 同时更新 document Title
    (0, react_1.useEffect)(() => {
        document.title = appTitle;
    }, [appTitle]);
    if (hidden) {
        return null;
    }
    return (react_1.default.createElement("div", { className: header_module_less_1.default.title_info, ref: ref },
        react_1.default.createElement("span", { ref: spanRef }, appTitle)));
});
//# sourceMappingURL=header.view.js.map