"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ElectronBasicContribution = exports.ElectronBasicModule = void 0;
const tslib_1 = require("tslib");
const di_1 = require("@opensumi/di");
const ide_core_browser_1 = require("@opensumi/ide-core-browser");
const layout_1 = require("@opensumi/ide-core-browser/lib/layout");
const next_1 = require("@opensumi/ide-core-browser/lib/menu/next");
const electron_1 = require("@opensumi/ide-core-browser/lib/menu/next/renderer/ctxmenu/electron");
const electron_2 = require("@opensumi/ide-core-common/lib/electron");
const browser_1 = require("@opensumi/ide-editor/lib/browser");
const common_1 = require("@opensumi/ide-overlay/lib/common");
const header_1 = require("../common/header");
const clipboard_1 = require("./clipboard");
const dialog_1 = require("./dialog");
const electron_preference_contribution_1 = require("./electron-preference.contribution");
const header_service_1 = require("./header/header.service");
const header_view_1 = require("./header/header.view");
const contribution_1 = require("./welcome/contribution");
require("../common/i18n/setup");
let ElectronBasicModule = class ElectronBasicModule extends ide_core_browser_1.BrowserModule {
    constructor() {
        super(...arguments);
        this.providers = [
            {
                token: ide_core_browser_1.IElectronNativeDialogService,
                useClass: dialog_1.ElectronNativeDialogService,
            },
            {
                token: header_1.IElectronHeaderService,
                useClass: header_service_1.ElectronHeaderService,
            },
            ElectronBasicContribution,
            electron_preference_contribution_1.ElectronPreferenceContribution,
            contribution_1.WelcomeContribution,
        ];
    }
};
ElectronBasicModule = tslib_1.__decorate([
    (0, di_1.Injectable)()
], ElectronBasicModule);
exports.ElectronBasicModule = ElectronBasicModule;
const nativeRoles = [
    {
        name: 'undo',
        key: 'ctrlcmd+z',
        when: '!editorFocus',
    },
    {
        name: 'redo',
        key: 'ctrlcmd+shift+z',
        when: '!editorFocus',
    },
    {
        name: 'copy',
        key: 'ctrlcmd+c',
        when: '!editorFocus',
    },
    {
        name: 'paste',
        key: 'ctrlcmd+v',
        when: '!editorFocus',
    },
    {
        name: 'selectAll',
        key: 'ctrlcmd+a',
        when: '!editorFocus',
    },
    {
        name: 'cut',
        key: 'ctrlcmd+x',
        when: '!editorFocus',
    },
    {
        name: 'toggleDevTools',
        key: 'alt+ctrlcmd+i',
        label: '%window.toggleDevTools%',
    },
];
let ElectronBasicContribution = class ElectronBasicContribution {
    registerComponent(registry) {
        const top = this.config.layoutConfig[ide_core_browser_1.SlotLocation.top];
        if (top && top.modules) {
            const index = top.modules.indexOf('@opensumi/ide-menu-bar');
            if (index !== -1) {
                top.modules.splice(index, 1, 'electron-header');
            }
        }
        registry.register('electron-header', {
            id: 'electron-header',
            component: header_view_1.ElectronHeaderBar,
        }, {
            size: 27,
            containerId: 'electron-header',
        });
    }
    registerMenus(menuRegistry) {
        menuRegistry.registerMenuItem(next_1.MenuId.MenubarAppMenu, {
            command: {
                id: 'electron.about',
                label: '%common.about%',
            },
            group: '0_about',
            nativeRole: 'about',
        });
        menuRegistry.registerMenuItem(next_1.MenuId.MenubarHelpMenu, {
            command: {
                id: 'electron.toggleDevTools',
                label: '%window.toggleDevTools%',
            },
            nativeRole: 'toggledevtools',
        });
        menuRegistry.registerMenuItem(next_1.MenuId.MenubarHelpMenu, {
            command: {
                id: 'electron.reload',
                label: '%window.reload%',
            },
        });
        menuRegistry.registerMenuItem(next_1.MenuId.ExplorerContext, {
            command: 'electron.revealInFinder',
            group: '12_electron',
            order: 3,
        });
        menuRegistry.registerMenuItem(next_1.MenuId.EditorTitleContext, {
            command: 'electron.revealInFinderTab',
            group: '2_open',
            order: 3,
        });
    }
    registerCommands(commands) {
        nativeRoles.forEach((role) => {
            commands.registerCommand({
                id: 'electron.' + role.name,
                label: role.label,
            }, {
                execute: () => {
                    this.electronMainMenuService.runNativeRoleAction(role.name);
                },
            });
        });
        commands.registerCommand({
            id: 'electron.zoomIn',
            label: '%view.zoomIn%',
        }, {
            execute: () => {
                this.electronMainUIService.setZoomFactor(ide_core_browser_1.electronEnv.currentWebContentsId, {
                    delta: 0.1,
                });
            },
        });
        commands.registerCommand({
            id: 'electron.zoomOut',
            label: '%view.zoomOut%',
        }, {
            execute: () => {
                this.electronMainUIService.setZoomFactor(ide_core_browser_1.electronEnv.currentWebContentsId, {
                    delta: -0.1,
                });
            },
        });
        commands.registerCommand({
            id: 'electron.zoomReset',
            label: '%view.zoomReset%',
        }, {
            execute: () => {
                this.electronMainUIService.setZoomFactor(ide_core_browser_1.electronEnv.currentWebContentsId, {
                    value: 1,
                });
            },
        });
        commands.registerCommand({
            id: 'electron.reload',
            label: '%window.reload%',
        }, {
            execute: () => {
                this.electronMainLifeCycleService.reloadWindow(ide_core_browser_1.electronEnv.currentWindowId);
            },
        });
        commands.registerCommand({
            id: 'electron.revealInFinder',
            label: '%explorer.electron.revealInFinder%',
        }, {
            execute: (uri) => {
                if (uri && uri.scheme === ide_core_browser_1.Schemes.file) {
                    this.electronMainUIService.revealInFinder(uri.codeUri.fsPath);
                }
            },
        });
        commands.registerCommand({
            id: 'electron.revealInFinderTab',
            label: '%explorer.electron.revealInFinder%',
        }, {
            execute: ({ uri } = {}) => {
                if (uri && uri.scheme === ide_core_browser_1.Schemes.file) {
                    this.electronMainUIService.revealInFinder(uri.codeUri.fsPath);
                }
            },
        });
        commands.registerCommand({
            id: 'electron.openInSystemTerminal',
            label: '%explorer.electron.openInSystemTerminal%',
        }, {
            execute: (uri) => {
                if (uri && uri.scheme === ide_core_browser_1.Schemes.file) {
                    try {
                        this.electronMainUIService.revealInSystemTerminal(uri.codeUri.fsPath);
                    }
                    catch (e) {
                        this.logger.error(e);
                        this.messageService.error((0, ide_core_browser_1.formatLocalize)('explorer.electron.openInSystemTerminal.error', uri.displayName, e.message));
                    }
                }
            },
        });
    }
    registerKeybindings(keybindings) {
        nativeRoles.forEach((role) => {
            if (role.key) {
                keybindings.registerKeybinding({
                    command: 'electron.' + role.name,
                    keybinding: role.key,
                    when: role.when,
                    priority: Number.MIN_SAFE_INTEGER, // 永远在最后被命中
                });
            }
        });
        keybindings.registerKeybinding({
            command: 'electron.reload',
            keybinding: 'shift+ctrlcmd+r',
        });
        keybindings.registerKeybinding({
            command: 'electron.zoomIn',
            keybinding: ide_core_browser_1.isWindows ? 'alt+=' : 'ctrlcmd+=',
        });
        keybindings.registerKeybinding({
            command: 'electron.zoomOut',
            keybinding: ide_core_browser_1.isWindows ? 'alt+-' : 'ctrlcmd+-',
        });
        keybindings.registerKeybinding({
            command: 'electron.zoomReset',
            keybinding: ide_core_browser_1.isWindows ? 'alt+numpad0' : 'ctrlcmd+numpad0',
        });
    }
    onStart() {
        if (ide_core_browser_1.isOSX) {
            this.electronMenuBarService.start();
        }
        // 注册drag drop file的行为
        this.eventBus.on(browser_1.EditorGroupFileDropEvent, async (event) => {
            const payload = event.payload;
            // fileList 只能这样遍历
            for (let i = 0; i < payload.files.length; i++) {
                const file = payload.files[i];
                let group = event.payload.group;
                if (file.path) {
                    const fileURI = ide_core_browser_1.URI.file(file.path);
                    const options = {
                        index: event.payload.tabIndex !== -1 ? event.payload.tabIndex : undefined,
                    };
                    // 只有第一个才split
                    if (i === 0 && event.payload.position && event.payload.position !== browser_1.DragOverPosition.CENTER) {
                        options.split = (0, browser_1.getSplitActionFromDragDrop)(event.payload.position);
                    }
                    // 只有最后一个才可能为 preview
                    if (i < payload.files.length - 1) {
                        options.preview = false;
                    }
                    const res = await group.open(fileURI, options);
                    if (res) {
                        // split后当前group会变动
                        group = res.group;
                    }
                }
            }
        });
        // override broswer modules
        this.injector.overrideProviders({
            token: ide_core_browser_1.IClipboardService,
            useClass: clipboard_1.ElectronClipboardService,
        });
    }
};
tslib_1.__decorate([
    (0, di_1.Autowired)(ide_core_browser_1.AppConfig),
    tslib_1.__metadata("design:type", Object)
], ElectronBasicContribution.prototype, "config", void 0);
tslib_1.__decorate([
    (0, di_1.Autowired)(di_1.INJECTOR_TOKEN),
    tslib_1.__metadata("design:type", di_1.Injector)
], ElectronBasicContribution.prototype, "injector", void 0);
tslib_1.__decorate([
    (0, di_1.Autowired)(ide_core_browser_1.IEventBus),
    tslib_1.__metadata("design:type", Object)
], ElectronBasicContribution.prototype, "eventBus", void 0);
tslib_1.__decorate([
    (0, di_1.Autowired)(electron_1.IElectronMenuBarService),
    tslib_1.__metadata("design:type", Object)
], ElectronBasicContribution.prototype, "electronMenuBarService", void 0);
tslib_1.__decorate([
    (0, di_1.Autowired)(ide_core_browser_1.IElectronMainMenuService),
    tslib_1.__metadata("design:type", Object)
], ElectronBasicContribution.prototype, "electronMainMenuService", void 0);
tslib_1.__decorate([
    (0, di_1.Autowired)(electron_2.IElectronMainLifeCycleService),
    tslib_1.__metadata("design:type", Object)
], ElectronBasicContribution.prototype, "electronMainLifeCycleService", void 0);
tslib_1.__decorate([
    (0, di_1.Autowired)(electron_2.IElectronMainUIService),
    tslib_1.__metadata("design:type", Object)
], ElectronBasicContribution.prototype, "electronMainUIService", void 0);
tslib_1.__decorate([
    (0, di_1.Autowired)(common_1.IMessageService),
    tslib_1.__metadata("design:type", Object)
], ElectronBasicContribution.prototype, "messageService", void 0);
tslib_1.__decorate([
    (0, di_1.Autowired)(ide_core_browser_1.ILogger),
    tslib_1.__metadata("design:type", Object)
], ElectronBasicContribution.prototype, "logger", void 0);
ElectronBasicContribution = tslib_1.__decorate([
    (0, ide_core_browser_1.Domain)(layout_1.ComponentContribution, ide_core_browser_1.ClientAppContribution, next_1.MenuContribution, ide_core_browser_1.CommandContribution, ide_core_browser_1.KeybindingContribution)
], ElectronBasicContribution);
exports.ElectronBasicContribution = ElectronBasicContribution;
//# sourceMappingURL=index.js.map